# dzcb

Docs and supporting files

* [WALKTHROUGH](./WALKTHROUGH.md) - step-by-step guide for building codeplug
* [BETA](./BETA.md) - beta testing guidelines
  with github actions
* [HISTORY](./HISTORY.md) - motivation, criticism, and feature development history
